@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _MAIN_H
@@ -71,8 +71,8 @@ typedef struct {
 } REQ;
 
 /* Global variables */
-REQ *req;			/* Cmd line arguments */
-unsigned int debug;
+extern thread_master *master;
+extern REQ *req;		/* Cmd line arguments */
 
 /* Data buffer length description */
 #define BUFSIZE             1024
