@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <string.h>
@@ -31,29 +31,28 @@
 #include "ssl.h"
 #include "main.h"
 
-/* extern var */
-extern thread_master *master;
-extern SOCK *sock;
+/* global var */
+SOCK *sock = NULL;
 
 /* Close the descriptor */
 static void
-close_sock(SOCK * sock)
+close_sock(SOCK * sock_obj)
 {
-	if (sock->ssl) {
-		SSL_shutdown(sock->ssl);
-		SSL_free(sock->ssl);
+	if (sock_obj->ssl) {
+		SSL_shutdown(sock_obj->ssl);
+		SSL_free(sock_obj->ssl);
 	}
-	close(sock->fd);
+	close(sock_obj->fd);
 }
 
 /* Destroy the socket handler */
 void
-free_sock(SOCK * sock)
+free_sock(SOCK * sock_obj)
 {
-	DBG("Freeing fd:%d\n", sock->fd);
+	DBG("Freeing fd:%d\n", sock_obj->fd);
 
-	close_sock(sock);
-	FREE(sock);
+	close_sock(sock_obj);
+	FREE(sock_obj);
 }
 
 /* Init socket handler */
