@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _SOCK_H
@@ -43,8 +43,11 @@ typedef struct {
 	int total_size;
 } SOCK;
 
+/* global vars exported */
+extern SOCK *sock;
+
 /* Prototypes */
-extern void free_sock(SOCK * sock);
+extern void free_sock(SOCK * sock_obj);
 extern void init_sock(void);
 
 #endif
