@@ -5,7 +5,7 @@
  *
  * Part:        Healthcheckrs child process handling.
  *
- * Version:     $Id: check_daemon.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: check_daemon.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,49 +19,27 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "check_daemon.h"
 #include "check_parser.h"
 #include "check_data.h"
+#include "check_ssl.h"
 #include "check_api.h"
 #include "global_data.h"
 #include "ipwrapper.h"
 #include "ipvswrapper.h"
 #include "pidfile.h"
 #include "daemon.h"
+#include "signals.h"
 #include "list.h"
+#include "main.h"
 #include "memory.h"
 #include "parser.h"
-#include "watchdog.h"
 #include "vrrp_netlink.h"
 #include "vrrp_if.h"
 
-/* Global vars */
-check_conf_data *check_data;
-check_conf_data *old_check_data;
-int check_wdog_sd = -1;
-
-/* Healthchecker watchdog data */
-wdog_data check_wdog_data = {
-	"Healthcheck Child",
-	WDOG_CHECK,
-	-1,
-	-1,
-	start_check_child
-};
-
-/* Externals vars */
-extern thread_master *master;
-extern conf_data *data;
-extern unsigned int debug;
-extern int reload;
-extern pid_t checkers_child;
-extern char *conf_file;
-extern int init_ssl_ctx(void);
-extern int wdog_delay_check;
-
 /* Daemon stop sequence */
 static void
 stop_check(void)
@@ -88,9 +66,6 @@ stop_check(void)
 	keepalived_free_final("Healthcheck child process");
 #endif
 
-	/* free watchdog sd */
-	wdog_close(check_wdog_sd, WDOG_CHECK);
-
 	/*
 	 * Reached when terminate signal catched.
 	 * finally return to parent process.
@@ -145,16 +120,13 @@ start_check(void)
 		dump_check_data(check_data);
 	}
 
-	/* Register healthcheckers software watchdog */
-	check_wdog_sd = wdog_init(WDOG_CHECK);
-
 	/* Register checkers thread */
 	register_checkers_thread();
 }
 
 /* Reload handler */
 int
-reload_check_thread(thread * thread)
+reload_check_thread(thread * thread_obj)
 {
 	/* set the reloading flag */
 	SET_RELOAD;
@@ -164,12 +136,12 @@ reload_check_thread(thread * thread)
 	master = thread_make_master();
 	free_global_data(data);
 	free_checkers_queue();
+#ifdef _WITH_VRRP_
+	free_interface_queue();
+#endif
 	free_ssl();
 	ipvs_stop();
 
-	/* free watchdog sd */
-	wdog_close(check_wdog_sd, WDOG_CHECK);
-
 	/* Save previous conf data */
 	old_check_data = check_data;
 	check_data = NULL;
@@ -189,7 +161,8 @@ reload_check_thread(thread * thread)
 void
 sighup_check(int sig)
 {
-	syslog(LOG_INFO, "Reloading Healthchecker child process on signal");
+	syslog(LOG_INFO, "Reloading Healthchecker child processi(%d) on signal",
+	       checkers_child);
 	thread_add_event(master, reload_check_thread, NULL, 0);
 }
 
@@ -202,18 +175,41 @@ sigend_check(int sig)
 		thread_add_terminate_event(master);
 }
 
-/* VRRP Child signal handling */
+/* CHECK Child signal handling */
 void
 check_signal_init(void)
 {
+	signal_handler_init();
 	signal_set(SIGHUP, sighup_check);
 	signal_set(SIGINT, sigend_check);
 	signal_set(SIGTERM, sigend_check);
-	signal_set(SIGKILL, sigend_check);
+	signal_ignore(SIGPIPE);
 	signal_noignore_sigchld();
 }
 
-/* Register VRRP thread */
+/* CHECK Child respawning thread */
+int
+check_respawn_thread(thread * thread_obj)
+{
+	pid_t pid;
+
+	/* Fetch thread args */
+	pid = THREAD_CHILD_PID(thread_obj);
+
+	/* Restart respawning thread */
+	if (thread_obj->type == THREAD_CHILD_TIMEOUT) {
+		thread_add_child(master, check_respawn_thread, NULL,
+				 pid, RESPAWN_TIMER);
+		return 0;
+	}
+
+	/* We catch a SIGCHLD, handle it */
+	syslog(LOG_INFO, "Healthcheck child process(%d) died: Respawning", pid);
+	start_check_child();
+	return 0;
+}
+
+/* Register CHECK thread */
 int
 start_check_child(void)
 {
@@ -225,6 +221,7 @@ start_check_child(void)
 		return -1;
 	}
 
+#ifndef _DEBUG_
 	/* Initialize child process */
 	pid = fork();
 
@@ -233,19 +230,19 @@ start_check_child(void)
 			       , strerror(errno));
 		return -1;
 	} else if (pid) {
-		long poll_delay = (wdog_delay_check) ? wdog_delay_check : WATCHDOG_DELAY;
 		checkers_child = pid;
 		syslog(LOG_INFO, "Starting Healthcheck child process, pid=%d"
 			       , pid);
-		/* Connect child watchdog */
-		check_wdog_data.wdog_pid = pid;
-		thread_add_timer(master, wdog_boot_thread, &check_wdog_data,
-				 poll_delay);
+
+		/* Start respawning thread */
+		thread_add_child(master, check_respawn_thread, NULL,
+				 pid, RESPAWN_TIMER);
 		return 0;
 	}
 
-	/* Opening local VRRP syslog channel */
-	openlog(PROG_CHECK, LOG_PID | (debug & 1) ? LOG_CONS : 0, LOG_LOCAL2);
+	/* Opening local CHECK syslog channel */
+	openlog(PROG_CHECK, LOG_PID | (debug & 1) ? LOG_CONS : 0, 
+		(log_facility==LOG_DAEMON) ? LOG_LOCAL2 : log_facility);
 
 	/* Child process part, write pidfile */
 	if (!pidfile_write(CHECKERS_PID_FILE, getpid())) {
@@ -257,14 +254,15 @@ start_check_child(void)
 	thread_destroy_master(master);
 	master = thread_make_master();
 
-	/* Signal handling initialization */
-	check_signal_init();
-
 	/* change to / dir */
 	chdir("/");
 
 	/* Set mask */
 	umask(0);
+#endif
+
+	/* Signal handling initialization */
+	check_signal_init();
 
 	/* Start Healthcheck daemon */
 	start_check();
