@@ -5,7 +5,7 @@
  *
  * Part:        Healthcheckers dynamic data structure definition.
  *
- * Version:     $Id: check_data.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: check_data.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "check_data.h"
@@ -27,8 +27,9 @@
 #include "memory.h"
 #include "utils.h"
 
-/* Externals vars */
-extern check_conf_data *check_data;
+/* global vars */
+check_conf_data *check_data = NULL;
+check_conf_data *old_check_data = NULL;
 
 /* SSL facility functions */
 SSL_DATA *
@@ -326,27 +327,27 @@ alloc_check_data(void)
 }
 
 void
-free_check_data(check_conf_data *check_data)
+free_check_data(check_conf_data *check_data_obj)
 {
-	free_list(check_data->vs);
-	free_list(check_data->vs_group);
-	FREE(check_data);
+	free_list(check_data_obj->vs);
+	free_list(check_data_obj->vs_group);
+	FREE(check_data_obj);
 }
 
 void
-dump_check_data(check_conf_data *check_data)
+dump_check_data(check_conf_data *check_data_obj)
 {
-	if (check_data->ssl) {
+	if (check_data_obj->ssl) {
 		syslog(LOG_INFO, "------< SSL definitions >------");
 		dump_ssl();
 	}
-	if (!LIST_ISEMPTY(check_data->vs)) {
+	if (!LIST_ISEMPTY(check_data_obj->vs)) {
 		syslog(LOG_INFO, "------< LVS Topology >------");
 		syslog(LOG_INFO, " System is compiled with LVS v%d.%d.%d",
 		       NVERSION(IP_VS_VERSION_CODE));
-		if (!LIST_ISEMPTY(check_data->vs_group))
-			dump_list(check_data->vs_group);
-		dump_list(check_data->vs);
+		if (!LIST_ISEMPTY(check_data_obj->vs_group))
+			dump_list(check_data_obj->vs_group);
+		dump_list(check_data_obj->vs);
 	}
 	dump_checkers_queue();
 }
