@@ -5,7 +5,7 @@
  *
  * Part:        WEB CHECK. Common HTTP/SSL checker primitives.
  *
- * Version:     $Id: check_http.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: check_http.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Authors:     Alexandre Cassen, <acassen@linux-vs.org>
  *              Jan Holmberg, <jan@artech.net>
@@ -20,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <openssl/err.h>
@@ -38,23 +38,23 @@ int http_connect_thread(thread *);
 void
 free_url(void *data)
 {
-	url *url = data;
-	FREE(url->path);
-	FREE(url->digest);
-	FREE(url);
+	url *url_obj = data;
+	FREE(url_obj->path);
+	FREE(url_obj->digest);
+	FREE(url_obj);
 }
 
 void
 dump_url(void *data)
 {
-	url *url = data;
-	syslog(LOG_INFO, "   Checked url = %s", url->path);
-	if (url->digest)
+	url *url_obj = data;
+	syslog(LOG_INFO, "   Checked url = %s", url_obj->path);
+	if (url_obj->digest)
 		syslog(LOG_INFO, "           digest = %s",
-		       url->digest);
-	if (url->status_code)
+		       url_obj->digest);
+	if (url_obj->status_code)
 		syslog(LOG_INFO, "           HTTP Status Code = %d",
-		       url->status_code);
+		       url_obj->status_code);
 }
 
 void
@@ -168,27 +168,27 @@ void
 path_handler(vector strvec)
 {
 	http_get_checker *http_get_chk = CHECKER_GET();
-	url *url = LIST_TAIL_DATA(http_get_chk->url);
+	url *url_obj = LIST_TAIL_DATA(http_get_chk->url);
 
-	url->path = CHECKER_VALUE_STRING(strvec);
+	url_obj->path = CHECKER_VALUE_STRING(strvec);
 }
 
 void
 digest_handler(vector strvec)
 {
 	http_get_checker *http_get_chk = CHECKER_GET();
-	url *url = LIST_TAIL_DATA(http_get_chk->url);
+	url *url_obj = LIST_TAIL_DATA(http_get_chk->url);
 
-	url->digest = CHECKER_VALUE_STRING(strvec);
+	url_obj->digest = CHECKER_VALUE_STRING(strvec);
 }
 
 void
 status_code_handler(vector strvec)
 {
 	http_get_checker *http_get_chk = CHECKER_GET();
-	url *url = LIST_TAIL_DATA(http_get_chk->url);
+	url *url_obj = LIST_TAIL_DATA(http_get_chk->url);
 
-	url->status_code = CHECKER_VALUE_INT(strvec);
+	url_obj->status_code = CHECKER_VALUE_INT(strvec);
 }
 
 void
@@ -256,9 +256,9 @@ install_ssl_check_keyword(void)
  */
 
 uint16_t
-get_service_port(checker * checker)
+get_service_port(checker * checker_obj)
 {
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
 	uint16_t addr_port;
 
 	/*
@@ -268,7 +268,7 @@ get_service_port(checker * checker)
 	 *  then assume we want to use default ports for HTTP or HTTPS.
 	 *  Known as 'Layer3 stickyness'.
 	 */
-	addr_port = CHECKER_RPORT(checker);
+	addr_port = CHECKER_RPORT(checker_obj);
 	if (!addr_port)
 		addr_port =
 		    htons((http_get_check->proto == PROTO_SSL) ? 443 : 80);
@@ -287,18 +287,18 @@ get_service_port(checker * checker)
  * method == 2 => register a retry on url checker thread
  */
 int
-epilog(thread * thread, int method, int t, int c)
+epilog(thread * thread_obj, int method, int t, int c)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg);
-	uint16_t addr_port = get_service_port(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	REQ *req = HTTP_REQ(http_arg_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
 	long delay = 0;
 
 	if (method) {
-		http_arg->url_it += t ? t : -http_arg->url_it;
-		http_arg->retry_it += c ? c : -http_arg->retry_it;
+		http_arg_obj->url_it += t ? t : -http_arg_obj->url_it;
+		http_arg_obj->retry_it += c ? c : -http_arg_obj->retry_it;
 	}
 
 	/*
@@ -307,37 +307,37 @@ epilog(thread * thread, int method, int t, int c)
 	 * html buffer. This is sometime needed with some applications
 	 * servers.
 	 */
-	if (http_arg->retry_it > http_get_check->nb_get_retry-1) {
-		if (svr_checker_up(checker->id, checker->rs)) {
+	if (http_arg_obj->retry_it > http_get_check->nb_get_retry-1) {
+		if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
 			syslog(LOG_INFO, "Check on service [%s:%d] failed after %d retry."
-			       , inet_ntop2(CHECKER_RIP(checker))
-			       , ntohs(addr_port), http_arg->retry_it);
-			smtp_alert(thread->master, checker->rs, NULL, NULL,
+			       , inet_ntop2(CHECKER_RIP(checker_obj))
+			       , ntohs(addr_port), http_arg_obj->retry_it);
+			smtp_alert(checker_obj->rs, NULL, NULL,
 				   "DOWN",
 				   "=> CHECK failed on service"
 				   " : MD5 digest mismatch <=");
-			update_svr_checker_state(DOWN, checker->id
-						     , checker->vs
-						     , checker->rs);
+			update_svr_checker_state(DOWN, checker_obj->id
+						     , checker_obj->vs
+						     , checker_obj->rs);
 		}
 
 		/* Reset it counters */
-		http_arg->url_it = 0;
-		http_arg->retry_it = 0;
+		http_arg_obj->url_it = 0;
+		http_arg_obj->retry_it = 0;
 	}
 
 	/* register next timer thread */
 	switch (method) {
 	case 1:
 		if (req)
-			delay = checker->vs->delay_loop;
+			delay = checker_obj->vs->delay_loop;
 		else
 			delay =
 			    http_get_check->delay_before_retry;
 		break;
 	case 2:
-		if (http_arg->url_it == 0 && http_arg->retry_it == 0)
-			delay = checker->vs->delay_loop;
+		if (http_arg_obj->url_it == 0 && http_arg_obj->retry_it == 0)
+			delay = checker_obj->vs->delay_loop;
 		else
 			delay = http_get_check->delay_before_retry;
 		break;
@@ -350,64 +350,64 @@ epilog(thread * thread, int method, int t, int c)
 		if (req->buffer)
 			FREE(req->buffer);
 		FREE(req);
-		http_arg->req = NULL;
-		close(thread->u.fd);
+		http_arg_obj->req = NULL;
+		close(thread_obj->u.fd);
 	}
 
 	/* Register next checker thread */
-	thread_add_timer(thread->master, http_connect_thread, checker, delay);
+	thread_add_timer(thread_obj->master, http_connect_thread, checker_obj, delay);
 	return 0;
 }
 
 int
-timeout_epilog(thread * thread, char *smtp_msg, char *debug_msg)
+timeout_epilog(thread * thread_obj, char *smtp_msg, char *debug_msg)
 {
-	checker *checker = THREAD_ARG(thread);
-	uint16_t addr_port = get_service_port(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
 
 	syslog(LOG_INFO, "Timeout %s server [%s:%d].",
 	       debug_msg
-	       , inet_ntop2(CHECKER_RIP(checker))
+	       , inet_ntop2(CHECKER_RIP(checker_obj))
 	       , ntohs(addr_port));
 
 	/* check if server is currently alive */
-	if (svr_checker_up(checker->id, checker->rs)) {
-		smtp_alert(thread->master, checker->rs, NULL, NULL,
+	if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
+		smtp_alert(checker_obj->rs, NULL, NULL,
 			   "DOWN", smtp_msg);
-		update_svr_checker_state(DOWN, checker->id
-					     , checker->vs
-					     , checker->rs);
+		update_svr_checker_state(DOWN, checker_obj->id
+					     , checker_obj->vs
+					     , checker_obj->rs);
 	}
 
-	return epilog(thread, 1, 0, 0);
+	return epilog(thread_obj, 1, 0, 0);
 }
 
 /* return the url pointer of the current url iterator  */
 url *
 fetch_next_url(http_get_checker * http_get_check)
 {
-	http_arg *http_arg = HTTP_ARG(http_get_check);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
 
-	return list_element(http_get_check->url, http_arg->url_it);
+	return list_element(http_get_check->url, http_arg_obj->url_it);
 }
 
 /* Handle response */
 int
-http_handle_response(thread * thread, unsigned char digest[16]
+http_handle_response(thread * thread_obj, unsigned char digest[16]
 		     , int empty_buffer)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg);
-	uint16_t addr_port = get_service_port(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	REQ *req = HTTP_REQ(http_arg_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
 	int r, di = 0;
 	unsigned char *digest_tmp;
 	url *fetched_url = fetch_next_url(http_get_check);
 
 	/* First check if remote webserver returned data */
 	if (empty_buffer)
-		return timeout_epilog(thread, "=> CHECK failed on service"
+		return timeout_epilog(thread_obj, "=> CHECK failed on service"
 				      " : empty buffer received <=\n\n",
 				      "Read, no data received from ");
 
@@ -415,41 +415,41 @@ http_handle_response(thread * thread, unsigned char digest[16]
 	if (fetched_url->status_code) {
 		if (req->status_code != fetched_url->status_code) {
 			/* check if server is currently alive */
-			if (svr_checker_up(checker->id, checker->rs)) {
+			if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
 				syslog(LOG_INFO,
 				       "HTTP status code error to [%s:%d] url(%s)"
 				       ", status_code [%d].",
-				       inet_ntop2(CHECKER_RIP(checker)),
+				       inet_ntop2(CHECKER_RIP(checker_obj)),
 				       ntohs(addr_port), fetched_url->path,
 				       req->status_code);
-				smtp_alert(thread->master, checker->rs, NULL, NULL,
+				smtp_alert(checker_obj->rs, NULL, NULL,
 					   "DOWN",
 					   "=> CHECK failed on service"
 					   " : HTTP status code mismatch <=");
-				update_svr_checker_state(DOWN, checker->id
-							     , checker->vs
-							     , checker->rs);
+				update_svr_checker_state(DOWN, checker_obj->id
+							     , checker_obj->vs
+							     , checker_obj->rs);
 			} else {
 				DBG("HTTP Status_code to [%s:%d] url(%d) = [%d].",
-				    inet_ntop2(CHECKER_RIP(checker))
+				    inet_ntop2(CHECKER_RIP(checker_obj))
 				    , ntohs(addr_port)
-				    , http_arg->url_it + 1
+				    , http_arg_obj->url_it + 1
 				    , req->status_code);
 				/*
 				 * We set retry iterator to max value to not retry
 				 * when service is already know as die.
 				 */
-				http_arg->retry_it = http_get_check->nb_get_retry;
+				http_arg_obj->retry_it = http_get_check->nb_get_retry;
 			}
-			return epilog(thread, 2, 0, 1);
+			return epilog(thread_obj, 2, 0, 1);
 		} else {
-			if (!svr_checker_up(checker->id, checker->rs))
+			if (!svr_checker_up(checker_obj->id, checker_obj->rs))
 				syslog(LOG_INFO,
 				       "HTTP status code success to [%s:%d] url(%d).",
-				       inet_ntop2(CHECKER_RIP(checker))
+				       inet_ntop2(CHECKER_RIP(checker_obj))
 				       , ntohs(addr_port)
-				       , http_arg->url_it + 1);
-			return epilog(thread, 1, 1, 0) + 1;
+				       , http_arg_obj->url_it + 1);
+			return epilog(thread_obj, 1, 1, 0) + 1;
 		}
 	}
 
@@ -464,39 +464,39 @@ http_handle_response(thread * thread, unsigned char digest[16]
 
 		if (r) {
 			/* check if server is currently alive */
-			if (svr_checker_up(checker->id, checker->rs)) {
+			if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
 				syslog(LOG_INFO,
 				       "MD5 digest error to [%s:%d] url[%s]"
 				       ", MD5SUM [%s].",
-				       inet_ntop2(CHECKER_RIP(checker)),
+				       inet_ntop2(CHECKER_RIP(checker_obj)),
 				       ntohs(addr_port), fetched_url->path,
 				       digest_tmp);
 			} else {
 				DBG("MD5SUM to [%s:%d] url(%d) = [%s].",
-				    inet_ntop2(CHECKER_RIP(checker))
+				    inet_ntop2(CHECKER_RIP(checker_obj))
 				    , ntohs(addr_port)
-				    , http_arg->url_it + 1
+				    , http_arg_obj->url_it + 1
 				    , digest_tmp);
 				/*
 				 * We set retry iterator to max value to not retry
 				 * when service is already know as die.
 				 */
-				http_arg->retry_it = http_get_check->nb_get_retry;
+				http_arg_obj->retry_it = http_get_check->nb_get_retry;
 			}
 			FREE(digest_tmp);
-			return epilog(thread, 2, 0, 1);
+			return epilog(thread_obj, 2, 0, 1);
 		} else {
-			if (!svr_checker_up(checker->id, checker->rs))
+			if (!svr_checker_up(checker_obj->id, checker_obj->rs))
 				syslog(LOG_INFO, "MD5 digest success to [%s:%d] url(%d).",
-				       inet_ntop2(CHECKER_RIP(checker))
+				       inet_ntop2(CHECKER_RIP(checker_obj))
 				       , ntohs(addr_port)
-				       , http_arg->url_it + 1);
+				       , http_arg_obj->url_it + 1);
 			FREE(digest_tmp);
-			return epilog(thread, 1, 1, 0) + 1;
+			return epilog(thread_obj, 1, 1, 0) + 1;
 		}
 	}
 
-	return epilog(thread, 1, 0, 0) + 1;
+	return epilog(thread_obj, 1, 0, 0) + 1;
 }
 
 /* Handle response stream performing MD5 updates */
@@ -510,18 +510,17 @@ http_process_response(REQ *req, int r)
 			req->status_code = extract_status_code(req->buffer, req->len);
 			r = req->len - (req->extracted - req->buffer);
 			if (r) {
-				memcpy(req->buffer, req->extracted, r);
-				MD5_Update(&req->context, req->buffer,
-					   r);
+				memmove(req->buffer, req->extracted, r);
+				MD5_Update(&req->context, req->buffer, r);
 				r = 0;
 			}
 			req->len = r;
 		} else {
 			/* minimize buffer using no 2*CR/LF found yet */
-			if (req->len > 3) {
-				memcpy(req->buffer,
-				       req->buffer + req->len - 3, 3);
-				req->len = 3;
+			if (req->len > 4) {
+				memmove(req->buffer,
+					req->buffer + req->len - 4, 4);
+				req->len = 4;
 			}
 		}
 	} else if (req->len) {
@@ -535,41 +534,41 @@ http_process_response(REQ *req, int r)
 
 /* Asynchronous HTTP stream reader */
 int
-http_read_thread(thread * thread)
+http_read_thread(thread * thread_obj)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg);
-	uint16_t addr_port = get_service_port(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	REQ *req = HTTP_REQ(http_arg_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
 	unsigned char digest[16];
 	int r = 0;
 	int val;
 
 	/* Handle read timeout */
-	if (thread->type == THREAD_READ_TIMEOUT)
-		return timeout_epilog(thread, "=> HTTP CHECK failed on service"
+	if (thread_obj->type == THREAD_READ_TIMEOUT)
+		return timeout_epilog(thread_obj, "=> HTTP CHECK failed on service"
 				      " : recevice data <=\n\n", "HTTP read");
 
 	/* Set descriptor non blocking */
-	val = fcntl(thread->u.fd, F_GETFL, 0);
-	fcntl(thread->u.fd, F_SETFL, val | O_NONBLOCK);
+	val = fcntl(thread_obj->u.fd, F_GETFL, 0);
+	fcntl(thread_obj->u.fd, F_SETFL, val | O_NONBLOCK);
 
 	/* read the HTTP stream */
-	r = read(thread->u.fd, req->buffer + req->len,
+	r = read(thread_obj->u.fd, req->buffer + req->len,
 		 MAX_BUFFER_LENGTH - req->len);
 
 	/* restore descriptor flags */
-	fcntl(thread->u.fd, F_SETFL, val);
+	fcntl(thread_obj->u.fd, F_SETFL, val);
 
 	/* Test if data are ready */
-	if (r == -1 && errno == EAGAIN) {
+	if (r == -1 && (errno == EAGAIN || errno == EINTR)) {
 		syslog(LOG_INFO, "Read error with server [%s:%d]: %s",
-		       inet_ntop2(CHECKER_RIP(checker))
+		       inet_ntop2(CHECKER_RIP(checker_obj))
 		       , ntohs(addr_port)
 		       , strerror(errno));
-		thread_add_read(thread->master, http_read_thread, checker,
-				thread->u.fd, http_get_check->connection_to);
+		thread_add_read(thread_obj->master, http_read_thread, checker_obj,
+				thread_obj->u.fd, http_get_check->connection_to);
 		return 0;
 	}
 
@@ -580,24 +579,24 @@ http_read_thread(thread * thread)
 
 		if (r == -1) {
 			/* We have encourred a real read error */
-			if (svr_checker_up(checker->id, checker->rs)) {
+			if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
 				syslog(LOG_INFO, "Read error with server [%s:%d]: %s",
-				       inet_ntop2(CHECKER_RIP(checker))
+				       inet_ntop2(CHECKER_RIP(checker_obj))
 				       , ntohs(addr_port)
 				       , strerror(errno));
-				smtp_alert(thread->master, checker->rs, NULL, NULL,
+				smtp_alert(checker_obj->rs, NULL, NULL,
 					   "DOWN",
 					   "=> HTTP CHECK failed on service"
 					   " : cannot receive data <=");
-				update_svr_checker_state(DOWN, checker->id
-							     , checker->vs
-							     , checker->rs);
+				update_svr_checker_state(DOWN, checker_obj->id
+							     , checker_obj->vs
+							     , checker_obj->rs);
 			}
-			return epilog(thread, 1, 0, 0);
+			return epilog(thread_obj, 1, 0, 0);
 		}
 
 		/* Handle response stream */
-		http_handle_response(thread, digest, (!req->extracted) ? 1 : 0);
+		http_handle_response(thread_obj, digest, (!req->extracted) ? 1 : 0);
 
 	} else {
 
@@ -608,8 +607,8 @@ http_read_thread(thread * thread)
 		 * Register next http stream reader.
 		 * Register itself to not perturbe global I/O multiplexer.
 		 */
-		thread_add_read(thread->master, http_read_thread, checker,
-				thread->u.fd, http_get_check->connection_to);
+		thread_add_read(thread_obj->master, http_read_thread, checker_obj,
+				thread_obj->u.fd, http_get_check->connection_to);
 	}
 
 	return 0;
@@ -620,16 +619,16 @@ http_read_thread(thread * thread)
  * Apply trigger check to this result.
  */
 int
-http_response_thread(thread * thread)
+http_response_thread(thread * thread_obj)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	REQ *req = HTTP_REQ(http_arg_obj);
 
 	/* Handle read timeout */
-	if (thread->type == THREAD_READ_TIMEOUT)
-		return timeout_epilog(thread, "=> CHECK failed on service"
+	if (thread_obj->type == THREAD_READ_TIMEOUT)
+		return timeout_epilog(thread_obj, "=> CHECK failed on service"
 				      " : recevice data <=\n\n", "WEB read");
 
 	/* Allocate & clean the get buffer */
@@ -641,31 +640,32 @@ http_response_thread(thread * thread)
 
 	/* Register asynchronous http/ssl read thread */
 	if (http_get_check->proto == PROTO_SSL)
-		thread_add_read(thread->master, ssl_read_thread, checker,
-				thread->u.fd, http_get_check->connection_to);
+		thread_add_read(thread_obj->master, ssl_read_thread, checker_obj,
+				thread_obj->u.fd, http_get_check->connection_to);
 	else
-		thread_add_read(thread->master, http_read_thread, checker,
-				thread->u.fd, http_get_check->connection_to);
+		thread_add_read(thread_obj->master, http_read_thread, checker_obj,
+				thread_obj->u.fd, http_get_check->connection_to);
 	return 0;
 }
 
 /* remote Web server is connected, send it the get url query.  */
 int
-http_request_thread(thread * thread)
+http_request_thread(thread * thread_obj)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	REQ *req = HTTP_REQ(http_arg);
-	uint16_t addr_port = get_service_port(checker);
-	char *vhost = CHECKER_VHOST(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	REQ *req = HTTP_REQ(http_arg_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
+	char *vhost = CHECKER_VHOST(checker_obj);
 	char *str_request;
 	url *fetched_url;
 	int ret = 0;
+	int val;
 
 	/* Handle read timeout */
-	if (thread->type == THREAD_WRITE_TIMEOUT)
-		return timeout_epilog(thread, "=> CHECK failed on service"
+	if (thread_obj->type == THREAD_WRITE_TIMEOUT)
+		return timeout_epilog(thread_obj, "=> CHECK failed on service"
 				      " : read timeout <=\n\n",
 				      "Web read, timeout");
 
@@ -675,117 +675,123 @@ http_request_thread(thread * thread)
 	fetched_url = fetch_next_url(http_get_check);
 	snprintf(str_request, GET_BUFFER_LENGTH, REQUEST_TEMPLATE,
 		 fetched_url->path,
-		 (vhost) ? vhost : inet_ntop2(CHECKER_RIP(checker))
+		 (vhost) ? vhost : inet_ntop2(CHECKER_RIP(checker_obj))
 		 , ntohs(addr_port));
 	DBG("Processing url(%d) of [%s:%d].",
-	    http_arg->url_it + 1
-	    , inet_ntop2(CHECKER_RIP(checker))
+	    http_arg_obj->url_it + 1
+	    , inet_ntop2(CHECKER_RIP(checker_obj))
 	    , ntohs(addr_port));
 
+	/* Set descriptor non blocking */
+	val = fcntl(thread_obj->u.fd, F_GETFL, 0);
+	fcntl(thread_obj->u.fd, F_SETFL, val | O_NONBLOCK);
+
 	/* Send the GET request to remote Web server */
-	if (http_get_check->proto == PROTO_SSL)
-		ret =
-		    ssl_send_request(req->ssl, str_request,
-				     strlen(str_request));
-	else
-		ret =
-		    (send(thread->u.fd, str_request, strlen(str_request), 0) !=
-		     -1) ? 1 : 0;
+	if (http_get_check->proto == PROTO_SSL) {
+		ret = ssl_send_request(req->ssl, str_request,
+				       strlen(str_request));
+	} else {
+		ret = (send(thread_obj->u.fd, str_request, strlen(str_request), 0) !=
+		       -1) ? 1 : 0;
+	}
+
+	/* restore descriptor flags */
+	fcntl(thread_obj->u.fd, F_SETFL, val);
 
 	FREE(str_request);
 
 	if (!ret) {
 		syslog(LOG_INFO, "Cannot send get request to [%s:%d].",
-		       inet_ntop2(CHECKER_RIP(checker))
+		       inet_ntop2(CHECKER_RIP(checker_obj))
 		       , ntohs(addr_port));
 
 		/* check if server is currently alive */
-		if (svr_checker_up(checker->id, checker->rs)) {
-			smtp_alert(thread->master, checker->rs, NULL, NULL,
+		if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
+			smtp_alert(checker_obj->rs, NULL, NULL,
 				   "DOWN",
 				   "=> CHECK failed on service"
 				   " : cannot send data <=");
-			update_svr_checker_state(DOWN, checker->id
-						     , checker->vs
-						     , checker->rs);
+			update_svr_checker_state(DOWN, checker_obj->id
+						     , checker_obj->vs
+						     , checker_obj->rs);
 		}
-		return epilog(thread, 1, 0, 0);
+		return epilog(thread_obj, 1, 0, 0);
 	}
 
 	/* Register read timeouted thread */
-	thread_add_read(thread->master, http_response_thread, checker,
-			thread->u.fd, http_get_check->connection_to);
+	thread_add_read(thread_obj->master, http_response_thread, checker_obj,
+			thread_obj->u.fd, http_get_check->connection_to);
 	return 1;
 }
 
 /* WEB checkers threads */
 int
-http_check_thread(thread * thread)
+http_check_thread(thread * thread_obj)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	uint16_t addr_port = get_service_port(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	uint16_t addr_port = get_service_port(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
 #ifdef _DEBUG_
-	REQ *req = HTTP_REQ(http_arg);
+	REQ *req = HTTP_REQ(http_arg_obj);
 #endif
 	int ret = 1;
 	int status;
 
-	status = tcp_socket_state(thread->u.fd, thread, CHECKER_RIP(checker)
+	status = tcp_socket_state(thread_obj->u.fd, thread_obj, CHECKER_RIP(checker_obj)
 				  , addr_port, http_check_thread);
 	switch (status) {
 	case connect_error:
 		/* check if server is currently alive */
-		if (svr_checker_up(checker->id, checker->rs)) {
+		if (svr_checker_up(checker_obj->id, checker_obj->rs)) {
 			syslog(LOG_INFO, "Error connecting server [%s:%d].",
-			       inet_ntop2(CHECKER_RIP(checker))
+			       inet_ntop2(CHECKER_RIP(checker_obj))
 			       , ntohs(addr_port));
-			smtp_alert(thread->master, checker->rs, NULL, NULL,
+			smtp_alert(checker_obj->rs, NULL, NULL,
 				   "DOWN",
 				   "=> CHECK failed on service"
 				   " : connection error <=");
-			update_svr_checker_state(DOWN, checker->id
-						     , checker->vs
-						     , checker->rs);
+			update_svr_checker_state(DOWN, checker_obj->id
+						     , checker_obj->vs
+						     , checker_obj->rs);
 		}
-		return epilog(thread, 1, 0, 0);
+		return epilog(thread_obj, 1, 0, 0);
 		break;
 
 	case connect_timeout:
-		return timeout_epilog(thread, "==> CHECK failed on service"
+		return timeout_epilog(thread_obj, "==> CHECK failed on service"
 				      " : connection timeout <=\n\n",
 				      "connect, timeout");
 		break;
 
 	case connect_success:{
 			/* Allocate & clean request struct */
-			http_arg->req = (REQ *) MALLOC(sizeof (REQ));
+			http_arg_obj->req = (REQ *) MALLOC(sizeof (REQ));
 
 			if (http_get_check->proto == PROTO_SSL)
-				ret = ssl_connect(thread);
+				ret = ssl_connect(thread_obj);
 
 			if (ret) {
 				/* Remote WEB server is connected.
 				 * Register the next step thread ssl_request_thread.
 				 */
 				DBG("Remote Web server [%s:%d] connected.",
-				    inet_ntop2(CHECKER_RIP(checker)),
+				    inet_ntop2(CHECKER_RIP(checker_obj)),
 				    ntohs(addr_port));
-				thread_add_write(thread->master,
-						 http_request_thread, checker,
-						 thread->u.fd,
+				thread_add_write(thread_obj->master,
+						 http_request_thread, checker_obj,
+						 thread_obj->u.fd,
 						 http_get_check->connection_to);
 			} else {
 				syslog(LOG_INFO, "Connection trouble to: [%s:%d].",
-				       inet_ntop2(CHECKER_RIP(checker))
+				       inet_ntop2(CHECKER_RIP(checker_obj))
 				       , ntohs(addr_port));
 #ifdef _DEBUG_
 				if (http_get_check->proto == PROTO_SSL)
 					ssl_printerr(SSL_get_error
 						     (req->ssl, ret));
 #endif
-				return epilog(thread, 1, 0, 0);
+				return epilog(thread_obj, 1, 0, 0);
 			}
 		}
 		break;
@@ -795,12 +801,12 @@ http_check_thread(thread * thread)
 }
 
 int
-http_connect_thread(thread * thread)
+http_connect_thread(thread * thread_obj)
 {
-	checker *checker = THREAD_ARG(thread);
-	http_get_checker *http_get_check = CHECKER_ARG(checker);
-	http_arg *http_arg = HTTP_ARG(http_get_check);
-	uint16_t addr_port = get_service_port(checker);
+	checker *checker_obj = THREAD_ARG(thread_obj);
+	http_get_checker *http_get_check = CHECKER_ARG(checker_obj);
+	http_arg *http_arg_obj = HTTP_ARG(http_get_check);
+	uint16_t addr_port = get_service_port(checker_obj);
 	url *fetched_url;
 	enum connect_result status;
 	int fd;
@@ -809,9 +815,9 @@ http_connect_thread(thread * thread)
 	 * Register a new checker thread & return
 	 * if checker is disabled
 	 */
-	if (!CHECKER_ENABLED(checker)) {
-		thread_add_timer(thread->master, http_connect_thread, checker,
-				 checker->vs->delay_loop);
+	if (!CHECKER_ENABLED(checker_obj)) {
+		thread_add_timer(thread_obj->master, http_connect_thread, checker_obj,
+				 checker_obj->vs->delay_loop);
 		return 0;
 	}
 
@@ -823,18 +829,18 @@ http_connect_thread(thread * thread)
 		 * Check completed.
 		 * check if server is currently alive.
 		 */
-		if (!svr_checker_up(checker->id, checker->rs)) {
+		if (!svr_checker_up(checker_obj->id, checker_obj->rs)) {
 			syslog(LOG_INFO, "Remote Web server [%s:%d] succeed on service.",
-			       inet_ntop2(CHECKER_RIP(checker))
+			       inet_ntop2(CHECKER_RIP(checker_obj))
 			       , ntohs(addr_port));
-			smtp_alert(thread->master, checker->rs, NULL, NULL, "UP",
+			smtp_alert(checker_obj->rs, NULL, NULL, "UP",
 				   "=> CHECK succeed on service <=");
-			update_svr_checker_state(UP, checker->id
-						   , checker->vs
-						   , checker->rs);
+			update_svr_checker_state(UP, checker_obj->id
+						   , checker_obj->vs
+						   , checker_obj->rs);
 		}
-		http_arg->req = NULL;
-		return epilog(thread, 1, 0, 0) + 1;
+		http_arg_obj->req = NULL;
+		return epilog(thread_obj, 1, 0, 0) + 1;
 	}
 
 	/* Create the socket */
@@ -843,11 +849,11 @@ http_connect_thread(thread * thread)
 		return 0;
 	}
 
-	status = tcp_bind_connect(fd, CHECKER_RIP(checker), addr_port
+	status = tcp_bind_connect(fd, CHECKER_RIP(checker_obj), addr_port
 				  , http_get_check->bindto);
 
 	/* handle tcp connection status & register check worker thread */
-	tcp_connection_state(fd, status, thread, http_check_thread,
+	tcp_connection_state(fd, status, thread_obj, http_check_thread,
 			     http_get_check->connection_to);
 	return 0;
 }
