@@ -7,7 +7,7 @@
  *              data structure representation the conf file representing
  *              the loadbalanced server pool.
  *  
- * Version:     $Id: check_parser.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: check_parser.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
@@ -21,7 +21,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "check_parser.h"
@@ -33,10 +33,6 @@
 #include "memory.h"
 #include "utils.h"
 
-/* global defs */
-extern check_conf_data *check_data;
-extern unsigned long mem_allocated;
-
 /* SSL handlers */
 static void
 ssl_handler(vector strvec)
@@ -89,6 +85,10 @@ lbalgo_handler(vector strvec)
 	virtual_server *vs = LIST_TAIL_DATA(check_data->vs);
 	char *str = VECTOR_SLOT(strvec, 1);
 	int size = sizeof (vs->sched);
+	int str_len = strlen(str);
+
+	if (size > str_len)
+		size = str_len;
 
 	memcpy(vs->sched, str, size);
 }
@@ -128,6 +128,10 @@ pto_handler(vector strvec)
 	virtual_server *vs = LIST_TAIL_DATA(check_data->vs);
 	char *str = VECTOR_SLOT(strvec, 1);
 	int size = sizeof (vs->timeout_persistence);
+	int str_len = strlen(str);
+
+	if (size > str_len)
+		size = str_len;
 
 	memcpy(vs->timeout_persistence, str, size);
 }
@@ -202,8 +206,6 @@ notify_down_handler(vector strvec)
 vector
 check_init_keywords(void)
 {
-	keywords = vector_alloc();
-
 	/* global definitions mapping */
 	global_init_keywords();
 
