@@ -5,7 +5,7 @@
  *
  * Part:        Manipulation functions for IPVS & IPFW wrappers.
  *
- * Version:     $id: ipwrapper.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: ipwrapper.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "ipwrapper.h"
@@ -28,10 +28,6 @@
 #include "utils.h"
 #include "notify.h"
 
-/* extern global vars */
-extern check_conf_data *check_data;
-extern check_conf_data *old_check_data;
-
 /* Remove a realserver IPVS rule */
 static int
 clear_service_rs(list vs_group, virtual_server * vs, list l)
@@ -300,7 +296,32 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 			ipfw_cmd(IP_FW_CMD_ADD, vs, vs->s_svr);
 #endif
 		}
+	}
+}
 
+/* Store new weight in real_server struct and then update kernel. */
+void
+update_svr_wgt(int weight, virtual_server * vs, real_server * rs)
+{
+	char rsip[16], vsip[16];
+
+	if (weight != rs->weight) {
+		syslog(LOG_INFO, "Changing weight from %d to %d for %s service [%s:%d]"
+				 " of VS [%s:%d]"
+				 , rs->weight
+				 , weight
+				 , ISALIVE(rs) ? "active" : "inactive"
+				 , inet_ntoa2(SVR_IP(rs), rsip)
+				 , ntohs(SVR_PORT(rs))
+				 , (vs->vsgname) ? vs->vsgname : inet_ntoa2(SVR_IP(vs), vsip)
+				 , ntohs(SVR_PORT(vs)));
+		rs->weight = weight;
+		/*
+		 * Have weight change take effect now only if rs is alive.
+		 * If not, it will take effect later when it becomes alive.
+		 */
+		if (ISALIVE(rs))
+			ipvs_cmd(LVS_CMD_EDIT_DEST, check_data->vs_group, vs, rs);
 	}
 }
 
@@ -437,6 +458,9 @@ vs_exist(virtual_server * old_vs)
 	virtual_server *vs;
 	virtual_server_group *vsg;
 
+	if (LIST_ISEMPTY(l))
+		return 0;
+
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vs = ELEMENT_DATA(e);
 		if (VS_ISEQ(old_vs, vs)) {
@@ -475,6 +499,9 @@ rs_exist(real_server * old_rs, list l)
 	element e;
 	real_server *rs;
 
+	if (LIST_ISEMPTY(l))
+		return 0;
+
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		rs = ELEMENT_DATA(e);
 		if (RS_ISEQ(rs, old_rs)) {
@@ -500,6 +527,9 @@ get_rs_list(virtual_server * vs)
 	list l = check_data->vs;
 	virtual_server *vsvr;
 
+	if (LIST_ISEMPTY(l))
+		return NULL;
+
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vsvr = ELEMENT_DATA(e);
 		if (VS_ISEQ(vs, vsvr))
@@ -520,6 +550,10 @@ clear_diff_rs(virtual_server * old_vs)
 	real_server *rs;
 	char rsip[16], vsip[16];
 
+	/* If old vs didn't own rs then nothing return */
+	if (LIST_ISEMPTY(l))
+		return 1;
+
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		rs = ELEMENT_DATA(e);
 		if (!rs_exist(rs, new)) {
@@ -549,6 +583,10 @@ clear_diff_services(void)
 	list l = old_check_data->vs;
 	virtual_server *vs;
 
+	/* If old config didn't own vs then nothing return */
+	if (LIST_ISEMPTY(l))
+		return 1;
+
 	/* Remove diff entries from previous IPVS rules */
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vs = ELEMENT_DATA(e);
