@@ -5,7 +5,7 @@
  *
  * Part:        Main program structure.
  *
- * Version:     $Id: main.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: main.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <syslog.h>
@@ -75,66 +75,3 @@ xdaemon(int nochdir, int noclose, int exitflag)
 	umask(0);
 	return 0;
 }
-
-/*
- * SIGCHLD handler. Reap all zombie child.
- * WNOHANG prevent against parent process get
- * stuck waiting child termination.
- */
-void
-dummy_handler(int sig)
-{
-	/* Dummy */
-}
-
-void
-signal_noignore_sigchld(void)
-{
-	struct sigaction sa;
-	sigset_t mask;
-
-	/* Need to remove the NOCHLD flag */
-	sigemptyset(&mask);
-	sa.sa_handler = dummy_handler;
-	sa.sa_mask = mask;
-	sa.sa_flags = 0;
-
-	sigaction(SIGCHLD, &sa, NULL);
-
-	/* Block SIGCHLD so that we only receive it
-	 * when required (ie when its unblocked in the
-	 * select loop)
-	 */
-	sigaddset(&mask, SIGCHLD);
-	sigprocmask(SIG_BLOCK, &mask, NULL);
-}
-
-/* Signal wrapper */
-void *
-signal_set(int signo, void (*func) (int))
-{
-	int ret;
-	struct sigaction sig;
-	struct sigaction osig;
-
-	sig.sa_handler = func;
-	sigemptyset(&sig.sa_mask);
-	sig.sa_flags = 0;
-#ifdef SA_RESTART
-	sig.sa_flags |= SA_RESTART;
-#endif				/* SA_RESTART */
-
-	ret = sigaction(signo, &sig, &osig);
-
-	if (ret < 0)
-		return (SIG_ERR);
-	else
-		return (osig.sa_handler);
-}
-
-/* Signal remove */
-void *
-signal_ignore(int signo)
-{
-	return signal_set(signo, SIG_IGN);
-}
