@@ -5,7 +5,7 @@
  *
  * Part:        Main program structure.
  *
- * Version:     $Id: main.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: main.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,15 +19,23 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "main.h"
-#include "watchdog.h"
 #include "config.h"
+#include "signals.h"
+
+/* global var */
+char *conf_file = NULL;		/* Configuration file */
+int log_facility = LOG_DAEMON;	/* Optional logging facilities */
+pid_t vrrp_child = -1;		/* VRRP child process ID */
+pid_t checkers_child = -1;	/* Healthcheckers child process ID */
+int daemon_mode = 0;		/* VRRP/CHECK subsystem selection */
+int linkwatch = 0;		/* Use linkwatch kernel netlink reflection */
 
 /* Log facility table */
-struct {
+static struct {
 	int facility;
 } LOG_FACILITY[LOG_FACILITY_MAX + 1] = {
 	{LOG_LOCAL0}, {LOG_LOCAL1}, {LOG_LOCAL2}, {LOG_LOCAL3},
@@ -88,22 +96,11 @@ void
 sigend(int sig)
 {
 	int status;
-	sigset_t mask;
 
 	/* register the terminate thread */
 	syslog(LOG_INFO, "Terminating on signal");
 	thread_add_terminate_event(master);
 
-	/*
-	 * Signal child process.
-	 * Disable and unblock the SIGCHLD handler
-	 * so that wait() works.
-	 */
-	signal_ignore(SIGCHLD);
-	sigemptyset(&mask);
-	sigaddset(&mask, SIGCHLD);
-	sigprocmask(SIG_UNBLOCK, &mask, NULL);
-
 	if (vrrp_child > 0) {
 		kill(vrrp_child, SIGTERM);
 		waitpid(vrrp_child, &status, WNOHANG);
@@ -118,10 +115,11 @@ sigend(int sig)
 void
 signal_init(void)
 {
+	signal_handler_init();
 	signal_set(SIGHUP, sighup);
 	signal_set(SIGINT, sigend);
 	signal_set(SIGTERM, sigend);
-	signal_set(SIGKILL, sigend);
+	signal_ignore(SIGPIPE);
 	signal_noignore_sigchld();
 }
 
@@ -147,15 +145,13 @@ usage(const char *prog)
 		"  %s --dont-fork          -n    Dont fork the daemon process.\n"
 		"  %s --use-file           -f    Use the specified configuration file.\n"
 		"                                Default is /etc/keepalived/keepalived.conf.\n"
-		"  %s --wdog-vrrp          -R    Define VRRP watchdog polling delay. (default=5s)\n"
-		"  %s --wdog-check         -H    Define checkers watchdog polling delay. (default=5s)\n"
 		"  %s --dump-conf          -d    Dump the configuration data.\n"
 		"  %s --log-console        -l    Log message to local console.\n"
 		"  %s --log-detail         -D    Detailed log messages.\n"
 		"  %s --log-facility       -S    0-7 Set syslog facility to LOG_LOCAL[0-7]. (default=LOG_DAEMON)\n"
 		"  %s --help               -h    Display this short inlined help screen.\n"
 		"  %s --version            -v    Display the version number\n",
-		prog, prog, prog, prog, prog, prog, prog, prog, prog, prog,
+		prog, prog, prog, prog, prog, prog, prog, prog,
 		prog, prog, prog, prog);
 }
 
@@ -164,7 +160,7 @@ static void
 parse_cmdline(int argc, char **argv)
 {
 	poptContext context;
-	char *optarg = NULL;
+	char *option_arg = NULL;
 	int c;
 
 	struct poptOption options_table[] = {
@@ -172,14 +168,12 @@ parse_cmdline(int argc, char **argv)
 		{"help", 'h', POPT_ARG_NONE, NULL, 'h'},
 		{"log-console", 'l', POPT_ARG_NONE, NULL, 'l'},
 		{"log-detail", 'D', POPT_ARG_NONE, NULL, 'D'},
-		{"log-facility", 'S', POPT_ARG_STRING, &optarg, 'S'},
+		{"log-facility", 'S', POPT_ARG_STRING, &option_arg, 'S'},
 		{"dont-release-vrrp", 'V', POPT_ARG_NONE, NULL, 'V'},
 		{"dont-release-ipvs", 'I', POPT_ARG_NONE, NULL, 'I'},
 		{"dont-fork", 'n', POPT_ARG_NONE, NULL, 'n'},
 		{"dump-conf", 'd', POPT_ARG_NONE, NULL, 'd'},
-		{"use-file", 'f', POPT_ARG_STRING, &optarg, 'f'},
-		{"wdog-vrrp", 'R', POPT_ARG_STRING, &optarg, 'R'},
-		{"wdog-check", 'H', POPT_ARG_STRING, &optarg, 'H'},
+		{"use-file", 'f', POPT_ARG_STRING, &option_arg, 'f'},
 		{"vrrp", 'P', POPT_ARG_NONE, NULL, 'P'},
 		{"check", 'C', POPT_ARG_NONE, NULL, 'C'},
 		{NULL, 0, 0, NULL, 0}
@@ -220,16 +214,10 @@ parse_cmdline(int argc, char **argv)
 		debug |= 32;
 		break;
 	case 'S':
-		log_facility = LOG_FACILITY[atoi(optarg)].facility;
+		log_facility = LOG_FACILITY[atoi(option_arg)].facility;
 		break;
 	case 'f':
-		conf_file = optarg;
-		break;
-	case 'R':
-		wdog_delay_vrrp = atoi(optarg) * TIMER_HZ;
-		break;
-	case 'H':
-		wdog_delay_check = atoi(optarg) * TIMER_HZ;
+		conf_file = option_arg;
 		break;
 	case 'P':
 		daemon_mode |= 1;
@@ -261,16 +249,10 @@ parse_cmdline(int argc, char **argv)
 			debug |= 32;
 			break;
 		case 'S':
-			log_facility = LOG_FACILITY[atoi(optarg)].facility;
+			log_facility = LOG_FACILITY[atoi(option_arg)].facility;
 			break;
 		case 'f':
-			conf_file = optarg;
-			break;
-		case 'R':
-			wdog_delay_vrrp = atoi(optarg) * TIMER_HZ;
-			break;
-		case 'H':
-			wdog_delay_check = atoi(optarg) * TIMER_HZ;
+			conf_file = option_arg;
 			break;
 		case 'P':
 			daemon_mode |= 1;
@@ -282,8 +264,8 @@ parse_cmdline(int argc, char **argv)
 	}
 
 	/* check unexpected arguments */
-	if ((optarg = (char *) poptGetArg(context))) {
-		fprintf(stderr, "unexpected argument %s\n", optarg);
+	if ((option_arg = (char *) poptGetArg(context))) {
+		fprintf(stderr, "unexpected argument %s\n", option_arg);
 		return;
 	}
 
@@ -328,8 +310,10 @@ main(int argc, char **argv)
 			goto end;
 	}
 
+#ifndef _DEBUG_
 	/* Signal handling initialization  */
 	signal_init();
+#endif
 
 	/* Create the master thread */
 	master = thread_make_master();
@@ -337,11 +321,13 @@ main(int argc, char **argv)
 	/* Init daemon */
 	start_keepalived();
 
+#ifndef _DEBUG_
 	/* Launch the scheduling I/O multiplexer */
 	launch_scheduler();
 
 	/* Finish daemon process */
 	stop_keepalived();
+#endif
 
 	/*
 	 * Reached when terminate signal catched.
