@@ -5,7 +5,7 @@
  *
  * Part:        Daemon process handling.
  *
- * Version:     $Id: daemon.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: daemon.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _DAEMON_H
@@ -34,12 +34,8 @@
 #include <unistd.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <signal.h>
 
 /* prototype */
 extern pid_t xdaemon(int, int, int);
-extern void *signal_set(int signo, void (*func) (int));
-extern void *signal_ignore(int signo);
-extern void signal_noignore_sigchld(void);
 
 #endif
