@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_arp.c include file.
  *
- * Version:     $Id: vrrp_arp.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_arp.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_ARP_H
@@ -52,9 +52,9 @@ typedef struct _m_arphdr {
 	unsigned char __ar_tip[4];	/* Target IP address.  */
 } m_arphdr;
 
-/* Global var */
-char *garp_buffer;
-int garp_fd;
+/* Global vars exported */
+extern char *garp_buffer;
+extern int garp_fd;
 
 /* prototypes */
 extern void gratuitous_arp_init(void);
