@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_if.c include file.
  *
- * Version:     $Id: vrrp_if.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_if.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_IF_H
@@ -70,9 +70,6 @@ typedef struct _interface {
 	int linkbeat;		/* LinkBeat from MII BMSR req */
 } interface;
 
-/* Global interface queue */
-list if_queue;
-
 /* Macros */
 #define IF_NAME(X) ((X)->ifname)
 #define IF_INDEX(X) ((X)->ifindex)
@@ -98,10 +95,10 @@ extern int if_linkbeat(const interface *ifp);
 extern int if_mii_probe(const char *ifname);
 extern int if_ethtool_probe(const char *ifname);
 extern void if_add_queue(interface * ifp);
-extern int if_monitor_thread(thread * thread);
+extern int if_monitor_thread(thread * thread_obj);
 extern void init_interface_queue(void);
 extern void free_interface_queue(void);
-extern void dump_if(void *data);
+extern void dump_if(void *if_data_obj);
 extern int if_join_vrrp_group(int sd, interface * ifp, int proto);
 extern void if_leave_vrrp_group(int sd, interface * ifp);
 extern int if_setsockopt_bindtodevice(int sd, interface * ifp);
