@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_iproute.c include file.
  *
- * Version:     $Id: vrrp_iproute.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_iproute.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_IPROUTE_H
@@ -61,8 +61,8 @@ typedef struct _ip_route {
 /* prototypes */
 extern int netlink_route_ipv4(ip_route *iproute, int cmd);
 extern void netlink_rtlist_ipv4(list rt_list, int cmd);
-extern void free_iproute(void *data);
-extern void dump_iproute(void *data);
+extern void free_iproute(void *rt_data_obj);
+extern void dump_iproute(void *rt_data_obj);
 extern void alloc_route(list rt_list, vector strvec);
 extern void clear_diff_routes(list l, list n);
 extern void clear_diff_sroutes(void);
