@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_netlink.c include file.
  *
- * Version:     $Id: vrrp_netlink.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_netlink.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_NETLINK_H
@@ -48,13 +48,13 @@ struct nl_handle {
 /* Define types */
 #define NETLINK_TIMER (30 * TIMER_HZ)
 
-/* Our global netlink handler */
-struct nl_handle nl_kernel;	/* Kernel reflection channel */
-struct nl_handle nl_cmd;	/* Command channel */
+/* Global vars exported */
+extern struct nl_handle nl_kernel;	/* Kernel reflection channel */
+extern struct nl_handle nl_cmd;		/* Command channel */
 
 /* prototypes */
-extern int addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data);
-extern int addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data,
+extern int addattr32(struct nlmsghdr *n, int maxlen, int type, uint32_t data_obj);
+extern int addattr_l(struct nlmsghdr *n, int maxlen, int type, void *data_obj,
 		     int alen);
 extern char *netlink_scope_n2a(int scope);
 extern int netlink_scope_a2n(char *scope);
@@ -64,5 +64,6 @@ extern int netlink_talk(struct nl_handle *nl, struct nlmsghdr *n);
 extern int netlink_interface_lookup(void);
 extern int netlink_interface_refresh(void);
 extern void kernel_netlink_init(void);
+extern void kernel_netlink_close(void);
 
 #endif
