@@ -5,7 +5,7 @@
  *
  * Part:        vrrp_scheduler.c include file.
  * 
- * Version:     $Id: vrrp_scheduler.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_scheduler.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _VRRP_SCHEDULER_H
@@ -34,18 +34,7 @@
 
 /* local includes */
 #include "scheduler.h"
-
-/*
- * Our instance dispatcher use a socket pool.
- * That way we handle VRRP protocol type per
- * physical interface.
- */
-typedef struct {
-	int ifindex;
-	int proto;
-	int fd_in;
-	int fd_out;
-} sock;
+#include "vrrp_data.h"
 
 /* VRRP FSM Macro */
 #define VRRP_FSM_READ_TO(V)			\
@@ -70,7 +59,8 @@ do {						\
 } while (0)
 
 /* extern prototypes */
-extern int vrrp_dispatcher_init(thread * thread);
-extern int vrrp_read_dispatcher_thread(thread * thread);
+extern void vrrp_dispatcher_release(vrrp_conf_data * conf_data_obj);
+extern int vrrp_dispatcher_init(thread * thread_obj);
+extern int vrrp_read_dispatcher_thread(thread * thread_obj);
 
 #endif
