@@ -5,7 +5,7 @@
  *
  * Part:        VRRP child process handling.
  *
- * Version:     $Id: vrrp_daemon.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_daemon.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "vrrp_daemon.h"
@@ -35,36 +35,14 @@
 #include "global_data.h"
 #include "pidfile.h"
 #include "daemon.h"
+#include "signals.h"
 #ifdef _WITH_LVS_
   #include "ipvswrapper.h"
 #endif
 #include "list.h"
+#include "main.h"
 #include "memory.h"
 #include "parser.h"
-#include "watchdog.h"
-
-/* Global vars */
-vrrp_conf_data *vrrp_data;
-vrrp_conf_data *old_vrrp_data;
-int vrrp_wdog_sd = -1;
-
-/* VRRP watchdog data */
-wdog_data vrrp_wdog_data = {
-	"VRRP Child",
-	WDOG_VRRP,
-	-1,
-	-1,
-	start_vrrp_child
-};
-
-/* Externals vars */
-extern thread_master *master;
-extern conf_data *data;
-extern unsigned int debug;
-extern int reload;
-extern pid_t vrrp_child;
-extern char *conf_file;
-extern int wdog_delay_vrrp;
 
 /* Daemon stop sequence */
 static void
@@ -74,8 +52,8 @@ stop_vrrp(void)
 	thread_destroy_master(master);
 
 	/* Clear static entries */
-	netlink_iplist_ipv4(vrrp_data->static_addresses, IPADDRESS_DEL);
 	netlink_rtlist_ipv4(vrrp_data->static_routes, IPROUTE_DEL);
+	netlink_iplist_ipv4(vrrp_data->static_addresses, IPADDRESS_DEL);
 
 	if (!(debug & 8))
 		shutdown_vrrp_instances();
@@ -88,6 +66,7 @@ stop_vrrp(void)
 	/* Clean data */
 	free_global_data(data);
 	free_vrrp_data(vrrp_data);
+	free_vrrp_buffer();
 
 #ifdef _WITH_LVS_
 	/* Clean ipvs related */
@@ -98,9 +77,6 @@ stop_vrrp(void)
 	keepalived_free_final("VRRP Child process");
 #endif
 
-	/* free watchdog sd */
-	wdog_close(vrrp_wdog_sd, WDOG_VRRP);
-
 	/*
 	 * Reached when terminate signal catched.
 	 * finally return to parent process.
@@ -157,9 +133,6 @@ start_vrrp(void)
 		dump_vrrp_data(vrrp_data);
 	}
 
-	/* Register vrrp software watchdog */
-	vrrp_wdog_sd = wdog_init(WDOG_VRRP);
-
 	/* Init & start the VRRP packet dispatcher */
 	thread_add_event(master, vrrp_dispatcher_init, NULL,
 			 VRRP_DISPATCHER);
@@ -167,7 +140,7 @@ start_vrrp(void)
 
 /* Reload handler */
 int
-reload_vrrp_thread(thread * thread)
+reload_vrrp_thread(thread * thread_obj)
 {
 	/* set the reloading flag */
 	SET_RELOAD;
@@ -180,9 +153,6 @@ reload_vrrp_thread(thread * thread)
 	free_vrrp_buffer();
 	gratuitous_arp_close();
 
-	/* free watchdog sd */
-	wdog_close(vrrp_wdog_sd, WDOG_VRRP);
-
 	/* Save previous conf data */
 	old_vrrp_data = vrrp_data;
 	vrrp_data = NULL;
@@ -207,7 +177,8 @@ reload_vrrp_thread(thread * thread)
 void
 sighup_vrrp(int sig)
 {
-	syslog(LOG_INFO, "Reloading VRRP child process on signal");
+	syslog(LOG_INFO, "Reloading VRRP child process(%d) on signal",
+	       vrrp_child);
 	thread_add_event(master, reload_vrrp_thread, NULL, 0);
 }
 
@@ -224,18 +195,43 @@ sigend_vrrp(int sig)
 void
 vrrp_signal_init(void)
 {
+	signal_handler_init();
 	signal_set(SIGHUP, sighup_vrrp);
 	signal_set(SIGINT, sigend_vrrp);
 	signal_set(SIGTERM, sigend_vrrp);
-	signal_set(SIGKILL, sigend_vrrp);
+	signal_ignore(SIGPIPE);
 	signal_noignore_sigchld();
 }
 
+/* VRRP Child respawning thread */
+int
+vrrp_respawn_thread(thread * thread_obj)
+{
+	pid_t pid;
+
+	/* Fetch thread args */
+	pid = THREAD_CHILD_PID(thread_obj);
+
+	/* Restart respawning thread */
+	if (thread_obj->type == THREAD_CHILD_TIMEOUT) {
+		thread_add_child(master, vrrp_respawn_thread, NULL,
+				 pid, RESPAWN_TIMER);
+		return 0;
+	}
+
+	/* We catch a SIGCHLD, handle it */
+	syslog(LOG_INFO, "VRRP child process(%d) died: Respawning", pid);
+	start_vrrp_child();
+	return 0;
+}
+
 /* Register VRRP thread */
 int
 start_vrrp_child(void)
 {
+#ifndef _DEBUG_
 	pid_t pid;
+#endif
 
 	/* Dont start if pid is already running */
 	if (vrrp_running()) {
@@ -243,6 +239,7 @@ start_vrrp_child(void)
 		return -1;
 	}
 
+#ifndef _DEBUG_
 	/* Initialize child process */
 	pid = fork();
 
@@ -251,19 +248,19 @@ start_vrrp_child(void)
 			       , strerror(errno));
 		return -1;
 	} else if (pid) {
-		long poll_delay = (wdog_delay_vrrp) ? wdog_delay_vrrp : WATCHDOG_DELAY;
 		vrrp_child = pid;
 		syslog(LOG_INFO, "Starting VRRP child process, pid=%d"
 			       , pid);
-		/* Connect child watchdog */
-		vrrp_wdog_data.wdog_pid = pid;
-		thread_add_timer(master, wdog_boot_thread, &vrrp_wdog_data,
-				 poll_delay);
+
+		/* Start respawning thread */
+		thread_add_child(master, vrrp_respawn_thread, NULL,
+				 pid, RESPAWN_TIMER);
 		return 0;
 	}
 
 	/* Opening local VRRP syslog channel */
-	openlog(PROG_VRRP, LOG_PID | (debug & 1) ? LOG_CONS : 0, LOG_LOCAL1);
+	openlog(PROG_VRRP, LOG_PID | (debug & 1) ? LOG_CONS : 0,
+		(log_facility==LOG_DAEMON) ? LOG_LOCAL1 : log_facility);
 
 	/* Child process part, write pidfile */
 	if (!pidfile_write(VRRP_PID_FILE, getpid())) {
@@ -276,14 +273,15 @@ start_vrrp_child(void)
 	thread_destroy_master(master);
 	master = thread_make_master();
 
-	/* Signal handling initialization */
-	vrrp_signal_init();
-
 	/* change to / dir */
 	chdir("/");
 
 	/* Set mask */
 	umask(0);
+#endif
+
+	/* Signal handling initialization */
+	vrrp_signal_init();
 
 	/* Start VRRP daemon */
 	start_vrrp();
