@@ -5,7 +5,7 @@
  *
  * Part:        Interfaces manipulation.
  *
- * Version:     $Id: vrrp_if.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_if.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 /* global include */
@@ -57,8 +57,7 @@ typedef __uint8_t u8;
 #include "utils.h"
 
 /* Global vars */
-extern thread_master *master;
-extern vrrp_conf_data *vrrp_data;
+static list if_queue;
 static struct ifreq ifr;
 
 /* Helper functions */
@@ -69,6 +68,9 @@ if_get_by_ifindex(const int ifindex)
 	interface *ifp;
 	element e;
 
+	if (LIST_ISEMPTY(if_queue))
+		return NULL;
+
 	for (e = LIST_HEAD(if_queue); e; ELEMENT_NEXT(e)) {
 		ifp = ELEMENT_DATA(e);
 		if (ifp->ifindex == ifindex)
@@ -83,6 +85,9 @@ if_get_by_ifname(const char *ifname)
 	interface *ifp;
 	element e;
 
+	if (LIST_ISEMPTY(if_queue))
+		return NULL;
+
 	for (e = LIST_HEAD(if_queue); e; ELEMENT_NEXT(e)) {
 		ifp = ELEMENT_DATA(e);
 		if (!strcmp(ifp->ifname, ifname))
@@ -240,9 +245,9 @@ free_if(void *data)
 }
 
 void
-dump_if(void *data)
+dump_if(void *if_data_obj)
 {
-	interface *ifp = data;
+	interface *ifp = if_data_obj;
 
 	syslog(LOG_INFO, "------< NIC >------");
 	syslog(LOG_INFO, " Name = %s", ifp->ifname);
@@ -301,9 +306,9 @@ if_add_queue(interface * ifp)
 
 #ifndef _WITH_LINKWATCH_
 static int
-if_linkbeat_refresh_thread(thread * thread)
+if_linkbeat_refresh_thread(thread * thread_obj)
 {
-	interface *ifp = THREAD_ARG(thread);
+	interface *ifp = THREAD_ARG(thread_obj);
 
 	if (IF_MII_SUPPORTED(ifp))
 		ifp->linkbeat = (if_mii_probe(ifp->ifname)) ? 1 : 0;
@@ -366,8 +371,8 @@ free_interface_queue(void)
 {
 	if (!LIST_ISEMPTY(if_queue))
 		free_list(if_queue);
-	netlink_close(&nl_kernel);
-	netlink_close(&nl_cmd);
+	if_queue = NULL;
+	kernel_netlink_close();
 }
 
 void
@@ -422,7 +427,7 @@ if_leave_vrrp_group(int sd, interface *ifp)
 	int ret = 0;
 
 	/* If fd is -1 then we add a membership trouble */
-	if (sd < 0)
+	if (sd < 0 || !ifp)
 		return;
 
 	/* Leaving the VRRP multicast group */
