@@ -5,7 +5,7 @@
  *
  * Part:        NETLINK IPv4 address manipulation.
  *
- * Version:     $Id: vrrp_ipaddress.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_ipaddress.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 /* local include */
@@ -29,10 +29,6 @@
 #include "memory.h"
 #include "utils.h"
 
-/* extern global vars */
-extern vrrp_conf_data *vrrp_data;
-extern vrrp_conf_data *old_vrrp_data;
-
 /* Add/Delete IP address to a specific interface */
 int
 netlink_address_ipv4(ip_address *ipaddr, int cmd)
@@ -74,10 +70,14 @@ netlink_iplist_ipv4(list ip_list, int cmd)
 	if (LIST_ISEMPTY(ip_list))
 		return;
 
+	/*
+	 * If "--dont-release-vrrp" (debug & 8) is set then try to release
+	 * addresses that may be there, even if we didn't set them.
+	 */
 	for (e = LIST_HEAD(ip_list); e; ELEMENT_NEXT(e)) {
 		ipaddress = ELEMENT_DATA(e);
 		if ((cmd && !ipaddress->set) ||
-		    (!cmd && ipaddress->set)) {
+		    (!cmd && (ipaddress->set || debug & 8))) {
 			if (netlink_address_ipv4(ipaddress, cmd) > 0)
 				ipaddress->set = (cmd) ? 1 : 0;
 			else
@@ -88,14 +88,14 @@ netlink_iplist_ipv4(list ip_list, int cmd)
 
 /* IP address dump/allocation */
 void
-free_ipaddress(void *data)
+free_ipaddress(void *if_data_obj)
 {
-	FREE(data);
+	FREE(if_data_obj);
 }
 void
-dump_ipaddress(void *data)
+dump_ipaddress(void *if_data_obj)
 {
-	ip_address *ip_addr = data;
+	ip_address *ip_addr = if_data_obj;
 	syslog(LOG_INFO, "     %s/%d brd %s dev %s scope %s"
 	       , inet_ntop2(ip_addr->addr)
 	       , ip_addr->mask
@@ -127,6 +127,13 @@ alloc_ipaddress(list ip_list, vector strvec, interface *ifp)
 		/* cmd parsing */
 		if (!strcmp(str, "dev")) {
 			new->ifp = if_get_by_ifname(VECTOR_SLOT(strvec, ++i));
+			if (!new->ifp) {
+				syslog(LOG_INFO, "VRRP is trying to assign VIP to unknown %s"
+				       " interface !!! go out and fixe your conf !!!",
+				       (char *)VECTOR_SLOT(strvec, i));
+				FREE(new);
+				return;
+			}
 			new->ifindex = IF_INDEX(new->ifp);
 		} else if (!strcmp(str, "scope")) {
 			new->scope = netlink_scope_a2n(VECTOR_SLOT(strvec, ++i));
