@@ -5,7 +5,7 @@
  *
  * Part:        NETLINK IPv4 routes manipulation.
  *
- * Version:     $Id: vrrp_iproute.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_iproute.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 /* local include */
@@ -30,10 +30,6 @@
 #include "memory.h"
 #include "utils.h"
 
-/* extern global vars */
-extern vrrp_conf_data *vrrp_data;
-extern vrrp_conf_data *old_vrrp_data;
-
 /* Add/Delete IP route to/from a specific interface */
 int
 netlink_route_ipv4(ip_route *iproute, int cmd)
@@ -99,14 +95,14 @@ netlink_rtlist_ipv4(list rt_list, int cmd)
 
 /* Route dump/allocation */
 void
-free_iproute(void *data)
+free_iproute(void *rt_data_obj)
 {
-	FREE(data);
+	FREE(rt_data_obj);
 }
 void
-dump_iproute(void *data)
+dump_iproute(void *rt_data_obj)
 {
-	ip_route *route = data;
+	ip_route *route = rt_data_obj;
 	char *log_msg = MALLOC(100);
 	char *tmp = MALLOC(30);
 
@@ -147,6 +143,7 @@ alloc_route(list rt_list, vector strvec)
 {
 	ip_route *new;
 	uint32_t ipaddr = 0;
+	interface *ifp;
 	char *str;
 	int i = 0;
 
@@ -162,7 +159,15 @@ alloc_route(list rt_list, vector strvec)
 		} else if (!strcmp(str, "src")) {
 			inet_ston(VECTOR_SLOT(strvec, ++i), &new->src);
 		} else if (!strcmp(str, "dev") || !strcmp(str, "oif")) {
-			new->index = IF_INDEX(if_get_by_ifname(VECTOR_SLOT(strvec, ++i)));
+			ifp = if_get_by_ifname(VECTOR_SLOT(strvec, ++i));
+			if (!ifp) {
+				syslog(LOG_INFO, "VRRP is trying to assign VROUTE to unknown "
+				       "%s interface !!! go out and fixe your conf !!!",
+				       (char *)VECTOR_SLOT(strvec, i));
+				FREE(new);
+				return;
+			}
+			new->index = IF_INDEX(ifp);
 		} else if (!strcmp(str, "table")) {
 			new->table = atoi(VECTOR_SLOT(strvec, ++i));
 		} else if (!strcmp(str, "scope")) {
