@@ -5,7 +5,7 @@
  *
  * Part:        VRRP synchronization framework.
  *
- * Version:     $Id: vrrp_sync.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: vrrp_sync.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include "vrrp_sync.h"
@@ -28,10 +28,6 @@
 #include "vrrp_data.h"
 #include "smtp.h"
 
-/* Externals vars */
-extern thread_master *master;
-extern vrrp_conf_data *vrrp_data;
-
 /* Compute the new instance sands */
 void
 vrrp_init_instance_sands(vrrp_rt * vrrp)
@@ -78,9 +74,9 @@ vrrp_sync_set_group(vrrp_sgroup *vgroup)
 		str = VECTOR_SLOT(vgroup->iname, i);
 		vrrp = vrrp_get_instance(str);
 		if (vrrp) {
-			if (LIST_ISEMPTY(vgroup->index))
-				vgroup->index = alloc_list(NULL, NULL);
-			list_add(vgroup->index, vrrp);
+			if (LIST_ISEMPTY(vgroup->index_list))
+				vgroup->index_list = alloc_list(NULL, NULL);
+			list_add(vgroup->index_list, vrrp);
 			vrrp->sync = vgroup;
 		}
 	}
@@ -92,7 +88,7 @@ vrrp_sync_group_up(vrrp_sgroup * vgroup)
 {
 	vrrp_rt *vrrp;
 	element e;
-	list l = vgroup->index;
+	list l = vgroup->index_list;
 	int is_up = 0;
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
@@ -101,7 +97,7 @@ vrrp_sync_group_up(vrrp_sgroup * vgroup)
 			is_up++;
 	}
 
-	if (is_up == LIST_SIZE(vgroup->index)) {
+	if (is_up == LIST_SIZE(vgroup->index_list)) {
 		syslog(LOG_INFO, "Kernel is reporting: Group(%s) UP"
 			       , GROUP_NAME(vgroup));
 		return 1;
@@ -115,11 +111,11 @@ vrrp_sync_smtp_notifier(vrrp_sgroup *vgroup)
 {
 	if (vgroup->smtp_alert) {
 		if (GROUP_STATE(vgroup) == VRRP_STATE_MAST)
-			smtp_alert(master, NULL, NULL, vgroup,
+			smtp_alert(NULL, NULL, vgroup,
 				   "Entering MASTER state",
 				   "=> All VRRP group instances are now in MASTER state <=");
 		if (GROUP_STATE(vgroup) == VRRP_STATE_BACK)
-			smtp_alert(master, NULL, NULL, vgroup,
+			smtp_alert(NULL, NULL, vgroup,
 				   "Entering BACKUP state",
 				   "=> All VRRP group instances are now in BACKUP state <=");
 	}
@@ -144,7 +140,7 @@ vrrp_sync_master_election(vrrp_rt * vrrp)
 {
 	vrrp_rt *isync;
 	vrrp_sgroup *vgroup = vrrp->sync;
-	list l = vgroup->index;
+	list l = vgroup->index_list;
 	element e;
 
 	if (vrrp->wantstate != VRRP_STATE_GOTO_MASTER)
@@ -174,7 +170,7 @@ vrrp_sync_backup(vrrp_rt * vrrp)
 {
 	vrrp_rt *isync;
 	vrrp_sgroup *vgroup = vrrp->sync;
-	list l = vgroup->index;
+	list l = vgroup->index_list;
 	element e;
 
 	if (GROUP_STATE(vgroup) == VRRP_STATE_BACK)
@@ -202,7 +198,7 @@ vrrp_sync_master(vrrp_rt * vrrp)
 {
 	vrrp_rt *isync;
 	vrrp_sgroup *vgroup = vrrp->sync;
-	list l = vgroup->index;
+	list l = vgroup->index_list;
 	element e;
 
 	if (GROUP_STATE(vgroup) == VRRP_STATE_MAST)
@@ -232,7 +228,7 @@ vrrp_sync_fault(vrrp_rt * vrrp)
 {
 	vrrp_rt *isync;
 	vrrp_sgroup *vgroup = vrrp->sync;
-	list l = vgroup->index;
+	list l = vgroup->index_list;
 	element e;
 
 	if (GROUP_STATE(vgroup) == VRRP_STATE_FAULT)
