@@ -5,7 +5,7 @@
  *
  * Part:        memory.c include file.
  *
- * Version:     $Id: memory.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: memory.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Authors:     Alexandre Cassen, <acassen@linux-vs.org>
  *              Jan Holmberg, <jan@artech.net>
@@ -20,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _MEMORY_H
@@ -33,11 +33,7 @@
 #include <string.h>
 #include <assert.h>
 
-/* Global var */
-unsigned long mem_allocated;	/* Total memory used in Bytes */
-
 /* extern types */
-extern unsigned int debug;
 extern unsigned long mem_allocated;
 extern void *xalloc(unsigned long size);
 extern void *zalloc(unsigned long size);
@@ -49,14 +45,14 @@ extern void xfree(void *p);
 /* Local defines */
 #ifdef _DEBUG_
 
-#define MAX_ALLOC_LIST 1024
+#define MAX_ALLOC_LIST 2048
 
 #define MALLOC(n)    ( keepalived_malloc((n), \
-                      (__FILE__), (__FUNCTION__), (__LINE__)) )
+                      (__FILE__), (char *)(__FUNCTION__), (__LINE__)) )
 #define FREE(b)      ( keepalived_free((b), \
-                      (__FILE__), (__FUNCTION__), (__LINE__)) )
+                      (__FILE__), (char *)(__FUNCTION__), (__LINE__)) )
 #define REALLOC(b,n) ( keepalived_realloc((b), (n), \
-                      (__FILE__), (__FUNCTION__), (__LINE__)) )
+                      (__FILE__), (char *)(__FUNCTION__), (__LINE__)) )
 
 /* Memory debug prototypes defs */
 extern char *keepalived_malloc(unsigned long, char *, char *, int);
