@@ -5,7 +5,7 @@
  * 
  * Part:        cfreader.c include file.
  *  
- * Version:     $Id: parser.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: parser.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _PARSER_H
@@ -53,24 +53,26 @@ struct keyword {
 #define UNSET_RELOAD    (reload = 0)
 #define RELOAD_DELAY    5
 
-/* global var exported */
-vector keywords;
-FILE *stream;
+/* global vars exported */
+extern vector keywords;
+extern FILE *stream;
+extern int reload;
 
 /* Prototypes */
-extern void keyword_alloc(vector keywords, char *string, void (*handler) (vector));
+extern void keyword_alloc(vector keywords_vec, char *string, void (*handler) (vector));
+extern void keyword_alloc_sub(vector keywords_vec, char *string, void (*handler) (vector));
 extern void install_keyword_root(char *string, void (*handler) (vector));
 extern void install_sublevel(void);
 extern void install_sublevel_end(void);
 extern void install_keyword(char *string, void (*handler) (vector));
 extern void dump_keywords(vector keydump, int level);
-extern void free_keywords(vector keywords);
+extern void free_keywords(vector keywords_vec);
 extern vector alloc_strvec(char *string);
 extern int read_line(char *buf, int size);
 extern vector read_value_block(void);
 extern void alloc_value_block(vector strvec, void (*alloc_func) (vector));
 extern void *set_value(vector strvec);
-extern void process_stream(vector keywords);
+extern void process_stream(vector keywords_vec);
 extern void init_data(char *conf_file, vector (*init_keywords) (void));
 
 #endif
