@@ -5,7 +5,7 @@
  *
  * Part:        scheduler.c include file.
  *
- * Version:     $Id: scheduler.h,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: scheduler.h,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #ifndef _SCHEDULER_H
@@ -90,9 +90,9 @@ typedef struct _thread_master {
 #define THREAD_CHILD_TIMEOUT	9
 #define THREAD_TERMINATE	10
 
-
 /* MICRO SEC def */
 #define BOOTSTRAP_DELAY TIMER_HZ
+#define RESPAWN_TIMER	60*TIMER_HZ
 
 /* Macros. */
 #define THREAD_ARG(X) ((X)->arg)
@@ -101,6 +101,9 @@ typedef struct _thread_master {
 #define THREAD_CHILD_PID(X) ((X)->u.c.pid)
 #define THREAD_CHILD_STATUS(X) ((X)->u.c.status)
 
+/* global vars exported */
+extern thread_master *master;
+
 /* Prototypes. */
 extern thread_master *thread_make_master(void);
 extern thread *thread_add_terminate_event(thread_master * m);
@@ -115,10 +118,10 @@ extern thread *thread_add_child(thread_master * m, int (*func) (thread *)
 				, void *arg, pid_t pid, long timeout);
 extern thread *thread_add_event(thread_master * m, int (*func) (thread *)
 				, void *arg, int val);
-extern void thread_cancel(thread * thread);
+extern void thread_cancel(thread * thread_obj);
 extern void thread_cancel_event(thread_master * m, void *arg);
 extern thread *thread_fetch(thread_master * m, thread * fetch);
-extern void thread_call(thread * thread);
+extern void thread_call(thread * thread_obj);
 extern void launch_scheduler(void);
 
 #endif
