@@ -5,7 +5,7 @@
  * 
  * Part:        Timer manipulations.
  *  
- * Version:     $Id: timer.c,v 1.1.7 2004/04/04 23:28:05 acassen Exp $
+ * Version:     $Id: timer.c,v 1.1.11 2005/03/01 01:22:13 acassen Exp $
  * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
@@ -19,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2004 Alexandre Cassen, <acassen@linux-vs.org>
+ * Copyright (C) 2001-2005 Alexandre Cassen, <acassen@linux-vs.org>
  */
 
 #include <stdio.h>
@@ -96,13 +96,13 @@ timer_add_long(TIMEVAL a, long b)
 TIMEVAL
 timer_now(void)
 {
-	TIMEVAL timer_now;
+	TIMEVAL curr_time;
 
 	/* init timer */
-	TIMER_RESET(timer_now);
-	gettimeofday(&timer_now, NULL);
+	TIMER_RESET(curr_time);
+	gettimeofday(&curr_time, NULL);
 
-	return timer_now;
+	return curr_time;
 }
 
 /* sets and returns current time from system time */
